/**
 * @filename CachedFastImage.js
 * @author 何晏波
 * @QQ 1054539528
 * @date 2018/9/27
 * @Description: CachedFastImage本地缓存图片控件
 */
import React, {PureComponent} from "react";
import {TouchableOpacity, View, ViewStyle} from "react-native";
import FastImage from "react-native-fast-image";
const PropTypes = require('prop-types');


export default class CachedFastImage extends PureComponent {
    static propTypes = {
        style: PropTypes.func.isRequired,
        onPress: PropTypes.object.isRequired,
        source:PropTypes.any,
        ossImgName:PropTypes.any,
        resizeMode:PropTypes.any
    };

    constructor(props) {
        super(props);
    }

    render() {

        let {style, resizeMode, onPress, source, ossImgName} = this.props;

        if (this.props.children) {
            return (
                <TouchableOpacity disabled={!onPress} onPress={onPress} style={style}>
                    <View style={{flex:1}}>
                        <FastImage
                            style={{position: 'absolute', left: 0, top: 0, width: `100 %`, height: `100 %`}}
                            source={`${source}`.includes('http') ? {
                                uri: source,
                                priority: FastImage.priority.normal
                            } : global.useOssRemoteImage && ossImgName ? this.getImageRes(ossImgName) : source}
                            resizeMode={FastImage.resizeMode.stretch}
                        />
                        {
                            this.props.children
                        }
                    </View>
                </TouchableOpacity>
            );
        }
        return (
            <TouchableOpacity disabled={!onPress} onPress={onPress} style={style}>
                <FastImage
                    style={{flex:1}}
                    source={`${source}`.includes('http') ? {
                        uri: source,
                        priority: FastImage.priority.normal
                    } : global.useOssRemoteImage && ossImgName ? this.getImageRes(ossImgName) : source}
                    resizeMode={resizeMode ? resizeMode : FastImage.resizeMode.stretch}
                />
            </TouchableOpacity>);
    }

    /**
     * 判断资源头
     * @param字符检验
     * */
    getImageRes = (imageName) => {

        return {uri: `${global.ossBaseUrl}${imageName}`, priority: FastImage.priority.normal};
    }
}
